@@ -37,7 +37,11 @@ class PreviewJob;
 class Query;
 class ReadOnlyArchiveInterface;
 
-enum ArchiveError { NoError = 0, NoPlugin, FailedPlugin };
+enum ArchiveError {
+    NoError = 0,
+    NoPlugin,
+    FailedPlugin
+};
 
 class KERFUFFLE_EXPORT Archive : public QObject
 {
@@ -66,7 +70,11 @@ class KERFUFFLE_EXPORT Archive : public QObject
     Q_PROPERTY(QStringList encryptionMethods MEMBER m_encryptionMethods)
 
 public:
-    enum EncryptionType { Unencrypted, Encrypted, HeaderEncrypted };
+    enum EncryptionType {
+        Unencrypted,
+        Encrypted,
+        HeaderEncrypted
+    };
     Q_ENUM(EncryptionType)
 
     class Entry;
@@ -203,7 +211,7 @@ private:
      * @return A valid archive if the plugin could be loaded, an invalid one otherwise (with the FailedPlugin error set).
      */
     static Archive *create(const QString &fileName, Plugin *plugin, QObject *parent = nullptr);
-    ReadOnlyArchiveInterface *m_iface;
+    ReadOnlyArchiveInterface *m_iface = nullptr;
     bool m_isReadOnly;
     bool m_isSingleFolder;
     bool m_isMultiVolume;
